==> dif-data-translator-2.1.6-2-20141125.152418-2-sources.jar: pt/digitalis/dif/translator/TranslatorMappings.java <==
/**
 * 2009, Digitalis Informatica. All rights reserved.
 *
 * Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos num.9 - Piso -1 2780-666 Paco de Arcos Telefone:
 * (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */

package pt.digitalis.dif.translator;

import java.util.Map;

/**
 * Tanslation mappings for the translation engine
 *
 * @author Luis Pinto <a href="mailto:lpinto@digitalis.pt">lpinto@digitalis.pt</a><br/>
 * @created Dec 16, 2009
 */
public class TranslatorMappings {

    /**  */
    FieldsDictionary fieldsDictionary = null;

    /**  */
    Map<String, String> attributeMappings = null;

    /**
     * The list of Mappings
     *
     * @return the list of Attributes
     */
    public FieldsDictionary getFieldsDictionary()
    {
        return fieldsDictionary;
    }

    /**
     * The list of Mappings
     *
     * @return the list of Attributes
     */
    public Map<String, String> getMappings()
    {
        return attributeMappings;
    }

    /**
     * Modifier for the 'attributeMappings' attribute.
     *
     * @param attributeMappings the new attributeMappings value to set
     */
    public void setMappings(Map<String, String> attributeMappings)
    {
        this.attributeMappings = attributeMappings;
    }


    /**
     * Modifier for the 'fieldsDictionary' attribute.
     *
     * @param fieldsDictionary the new fieldsDictionary value to set
     */
    public void setFieldsDictionary(FieldsDictionary fieldsDictionary)
    {
        this.fieldsDictionary = fieldsDictionary;
    }

}

==> dif-data-translator-2.2.9-4-20170330.112519-1-sources.jar: pt/digitalis/dif/translator/TranslatorMappings.java <==
/**
 * 2009, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos
 * num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */

package pt.digitalis.dif.translator;

import java.util.Map;

/**
 * Tanslation mappings for the translation engine
 *
 * @author Luis Pinto <a href="mailto:lpinto@digitalis.pt">lpinto@digitalis.pt</a><br/>
 * @created Dec 16, 2009
 */
public class TranslatorMappings {

    /**  */
    Map<String, String> attributeMappings = null;

    /**  */
    FieldsDictionary fieldsDictionary = null;

    /**
     * The list of Mappings
     *
     * @return the list of Attributes
     */
    public FieldsDictionary getFieldsDictionary()
    {
        return fieldsDictionary;
    }

    /**
     * The list of Mappings
     *
     * @return the list of Attributes
     */
    public Map<String, String> getMappings()
    {
        return attributeMappings;
    }

    /**
     * Modifier for the 'fieldsDictionary' attribute.
     *
     * @param fieldsDictionary
     *            the new fieldsDictionary value to set
     */
    public void setFieldsDictionary(FieldsDictionary fieldsDictionary)
    {
        this.fieldsDictionary = fieldsDictionary;
    }

    /**
     * Modifier for the 'attributeMappings' attribute.
     *
     * @param attributeMappings
     *            the new attributeMappings value to set
     */
    public void setMappings(Map<String, String> attributeMappings)
    {
        this.attributeMappings = attributeMappings;
    }

}
